"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fsScandir = require("@nodelib/fs.scandir");
const common = require("./common");
class SyncReader {
    constructor(_root, _settings) {
        this._root = _root;
        this._settings = _settings;
        this._scandir = fsScandir.scandirSync;
        this._storage = new Set();
        this._queue = new Set();
    }
    read() {
        this._pushToQueue(this._root);
        this._handleQueue();
        return Array.from(this._storage);
    }
    _pushToQueue(dir) {
        this._queue.add(dir);
    }
    _handleQueue() {
        for (const item of this._queue.values()) {
            this._handleDirectory(item);
        }
    }
    _handleDirectory(dir) {
        try {
            const entries = this._scandir(dir, this._settings.fsScandirSettings);
            for (const entry of entries) {
                this._handleEntry(entry);
            }
        }
        catch (error) {
            this._handleError(error);
        }
    }
    _handleError(error) {
        if (!common.isFatalError(this._settings, error)) {
            return;
        }
        throw error;
    }
    _handleEntry(entry) {
        const fullpath = entry.path;
        if (this._settings.basePath !== null) {
            entry.path = common.setBasePathForEntryPath(fullpath, this._root, this._settings.basePath);
        }
        if (common.isAppliedFilter(this._settings.entryFilter, entry)) {
            this._pushToStorage(entry);
        }
        if (entry.dirent.isDirectory() && common.isAppliedFilter(this._settings.deepFilter, entry)) {
            this._handleDirectory(fullpath);
        }
    }
    _pushToStorage(entry) {
        this._storage.add(entry);
    }
}
exports.default = SyncReader;
